Chromium Code Reviews
chromiumcodereview-hr@appspot.gserviceaccount.com (chromiumcodereview-hr) | Please choose your nickname with Settings | Help | Chromium Project | Gerrit Changes | Sign out
(816)

Unified Diff: runtime/lib/stacktrace.h

Issue 2572563004: Improve the casing of Stackmap and Stacktrace. (Closed)
Patch Set: Build fixes Created 4 years ago
Use n/p to move between diff chunks; N/P to move between comments. Draft comments are only viewable by you.
Jump to:
View side-by-side diff with in-line comments
Download patch
« no previous file with comments | « runtime/lib/object.cc ('k') | runtime/lib/stacktrace.cc » ('j') | no next file with comments »
Expand Comments ('e') | Collapse Comments ('c') | Show Comments Hide Comments ('s')
Index: runtime/lib/stacktrace.h
diff --git a/runtime/lib/stacktrace.h b/runtime/lib/stacktrace.h
index e6bccae510603532ba291ed443089384bcf197ae..fe67a9dcd9723ee19b778aba3b86dc901e35a0b0 100644
--- a/runtime/lib/stacktrace.h
+++ b/runtime/lib/stacktrace.h
@@ -7,14 +7,14 @@
namespace dart {
-class Stacktrace;
+class StackTrace;
-// Creates a Stacktrace object from the current stack. Skips the
+// Creates a StackTrace object from the current stack. Skips the
// first skip_frames Dart frames.
//
// This function is exposed to provide stack trace printing in
// assertion failures, etc.
-const Stacktrace& GetCurrentStacktrace(int skip_frames);
+const StackTrace& GetCurrentStackTrace(int skip_frames);
} // namespace dart
« no previous file with comments | « runtime/lib/object.cc ('k') | runtime/lib/stacktrace.cc » ('j') | no next file with comments »

Powered by Google App Engine
This is Rietveld 408576698